markuptools.Markup
==================

.. inheritance-diagram:: abjad.tools.markuptools.Markup.Markup.Markup
   :private-bases:

.. autoclass:: abjad.tools.markuptools.Markup.Markup.Markup

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.contents_string

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.format

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.markup_name

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.start_component

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.style_string

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.Markup.direction

   .. note:: Inherited from :py:class:`marktools._DirectedMark <abjad.tools.marktools._DirectedMark._DirectedMark._DirectedMark>`

Methods
-------

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.attach

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.detach

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Special Methods
---------------

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__call__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__delattr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__eq__

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__hash__

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__ne__

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__repr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.markuptools.Markup.Markup.Markup.__str__
